@@ -1,5 +1,7 @@
 from Products.Five import BrowserView
 from Products.CMFCore.utils import getToolByName
+import json
+
 try:
     from collective.flowplayer.interfaces import IFlowPlayable
     FLOWPLAYER_EXISTS = True
@@ -35,8 +37,12 @@ class GetMediaShowItemView(BrowserView):
         title = self.sanitizeStringForJson(title)    
         description = self.sanitizeStringForJson(description)
         
-            
-        jsonStr = '{"title": "'+title+'", "description": "'+description+'", "type": "'+type+'", "media": {"url": "'+media+'", "type" : "'+mediaType+'"}}'
+        #python to json encoding
+        jsonStr = json.dumps({"title": title, "description":description, "type": type, "media": {"url": media, "type": mediaType}})
+        
+        #Manual encoding 
+        #jsonStr = '{"title": "'+title+'", "description": "'+description+'", "type": "'+type+'", "media": {"url": "'+media+'", "type//" : "'+mediaType+'"}}'
+        
         if callback is not None:
             return callback +'(' + jsonStr + ')'
         else:
@@ -114,16 +120,26 @@ class MediaShowListingView(BrowserView):
             results = catalog.searchResults(item.getQuery())
         else:
             results = []
+         
+        
+        resultArray = []
+        
+        #Python to JSON encoding
+        for res in results: 
+            resultArray.append({"url": res.getURL(), "UID": res["UID"]})
             
-        jsonStr = "["
-        for res in results:
-            if(self.getMediaURL(res.getObject()) != ""):
-                jsonStr += '{"url" : "'+res.getURL()+'", "UID" : "'+res["UID"]+'"}'
-                jsonStr += ","
+        jsonStr = json.dumps(resultArray)
             
-        if jsonStr != "[":
-            jsonStr = jsonStr[:-1]
-        jsonStr += "]"
+        #Manual encoding 
+        #jsonStr = "["
+        #for res in results:
+        #    if(self.getMediaURL(res.getObject()) != ""):
+        #        jsonStr += '{"url" : "'+res.getURL()+'", "UID" : "'+res["UID"]+'"}'
+        #        jsonStr += ","
+        #    
+        #if jsonStr != "[":
+        #    jsonStr = jsonStr[:-1]
+        #jsonStr += "]"
         
         if callback is not None:
             return callback +'(' + jsonStr + ')'
